@@ -15,7 +15,7 @@ testthat::context('core tex function')
     
   }
   
-  path <- file.path(testthat::test_path('tex'))
+  path <- file.path(tempdir(),'tex')
   
   dir.create(path)
   
@@ -23,6 +23,8 @@ testthat::context('core tex function')
   
   testthat::skip_on_travis()
   
+  testthat::skip_on_cran()
+  
   testthat::describe('porting to tex',{
   
       x <- texPreview::texPreview(obj = xtable::xtable(head(iris,10)))
@@ -79,9 +81,11 @@ testthat::context('core tex function')
   
   testthat::describe('html output',{
   
-    it('print to console the html script', {
+    it('return magick object', {
       
-      expect_output(texPreview::texPreview(obj = xtable::xtable(head(iris,10))))
+      x <- texPreview::texPreview(obj = xtable::xtable(head(iris,10)))
+      
+      testthat::expect_true(inherits(x,"magick-image"))
       
     })
   
@@ -93,10 +97,10 @@ testthat::context('core tex function')
   
   testthat::describe('use svg device',{
   
-    x <- texPreview::texPreview(obj = xtable::xtable(head(iris,10)))
+    x <- texPreview::texPreview(obj = xtable::xtable(head(iris,10)), stem="danp-test")
   
     it('check if file created', {
-      expect_equal(length(list.files(path,pattern = 'svg$')),1)
+      testthat::expect_equal(length(list.files(path,pattern = 'svg$')),1)
     })
   
   })
@@ -122,9 +126,9 @@ testthat::context('core tex function')
     \\end{tabular}'
     
     x <- texPreview::texPreview(obj = tex)
-    
+
     it('validate benchmark', {
-      expect_equal(x,paste0(readLines(file.path(path,'tex_temp.tex')),collapse='\n'))
+      testthat::expect_equal(x,readLines(file.path(path,"tex_temp.tex")))
     })
     
   })
